Enum FrameAction
#[non_exhaustive]pub enum FrameAction {
Minimize,
Maximize,
UnMaximize,
Close,
Move,
Resize(ResizeEdge),
ShowMenu(i32, i32),
}Available on crate feature
wayland and Linux only.Expand description
The Frame action user should perform in responce to mouse click events.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Minimize
The window should be minimized.
Maximize
The window should be maximized.
UnMaximize
The window should be unmaximized.
Close
The window should be closed.
Move
An interactive move should be started.
Resize(ResizeEdge)
An interactive resize should be started with the provided edge.
ShowMenu(i32, i32)
Show window menu.
The coordinates are relative to the base surface, as in should be
directly passed to the xdg_toplevel::show_window_menu.