Enum FrameClick
#[non_exhaustive]pub enum FrameClick {
Normal,
Alternate,
}Available on crate feature
wayland and Linux only.Expand description
The user clicked or touched the decoractions frame.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Normal
The user done normal click, likely with left mouse button or single finger touch.
Alternate
The user done right mouse click or some touch sequence that was treated as alternate click.
The alternate click exists solely to provide alternative action, like show window menu when doing right mouse button cilck on the header decorations, nothing more.