Struct WindowManagerCapabilities
pub struct WindowManagerCapabilities(/* private fields */);wayland and Linux only.Expand description
The capabilities of the window manager.
This is a hint to hide UI elements which provide functionality not supported by compositor.
Implementations
impl WindowManagerCapabilities
impl WindowManagerCapabilities
pub const WINDOW_MENU: WindowManagerCapabilities
pub const WINDOW_MENU: WindowManagerCapabilities
show_window_menu is available.
pub const MAXIMIZE: WindowManagerCapabilities
pub const MAXIMIZE: WindowManagerCapabilities
Window can be maximized and unmaximized.
pub const FULLSCREEN: WindowManagerCapabilities
pub const FULLSCREEN: WindowManagerCapabilities
Window can be fullscreened and unfullscreened.
pub const MINIMIZE: WindowManagerCapabilities
pub const MINIMIZE: WindowManagerCapabilities
Window could be minimized.
impl WindowManagerCapabilities
impl WindowManagerCapabilities
pub const fn empty() -> WindowManagerCapabilities
pub const fn empty() -> WindowManagerCapabilities
Get a flags value with all bits unset.
pub const fn all() -> WindowManagerCapabilities
pub const fn all() -> WindowManagerCapabilities
Get a flags value with all known bits set.
pub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u16) -> Option<WindowManagerCapabilities>
pub const fn from_bits(bits: u16) -> Option<WindowManagerCapabilities>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u16) -> WindowManagerCapabilities
pub const fn from_bits_truncate(bits: u16) -> WindowManagerCapabilities
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u16) -> WindowManagerCapabilities
pub const fn from_bits_retain(bits: u16) -> WindowManagerCapabilities
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<WindowManagerCapabilities>
pub fn from_name(name: &str) -> Option<WindowManagerCapabilities>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: WindowManagerCapabilities) -> bool
pub const fn intersects(&self, other: WindowManagerCapabilities) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: WindowManagerCapabilities) -> bool
pub const fn contains(&self, other: WindowManagerCapabilities) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: WindowManagerCapabilities)
pub fn insert(&mut self, other: WindowManagerCapabilities)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: WindowManagerCapabilities)
pub fn remove(&mut self, other: WindowManagerCapabilities)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: WindowManagerCapabilities)
pub fn toggle(&mut self, other: WindowManagerCapabilities)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: WindowManagerCapabilities, value: bool)
pub fn set(&mut self, other: WindowManagerCapabilities, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: WindowManagerCapabilities,
) -> WindowManagerCapabilities
pub const fn intersection( self, other: WindowManagerCapabilities, ) -> WindowManagerCapabilities
The bitwise and (&) of the bits in self and other.
pub const fn union(
self,
other: WindowManagerCapabilities,
) -> WindowManagerCapabilities
pub const fn union( self, other: WindowManagerCapabilities, ) -> WindowManagerCapabilities
The bitwise or (|) of the bits in self and other.
pub const fn difference(
self,
other: WindowManagerCapabilities,
) -> WindowManagerCapabilities
pub const fn difference( self, other: WindowManagerCapabilities, ) -> WindowManagerCapabilities
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: WindowManagerCapabilities,
) -> WindowManagerCapabilities
pub const fn symmetric_difference( self, other: WindowManagerCapabilities, ) -> WindowManagerCapabilities
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> WindowManagerCapabilities
pub const fn complement(self) -> WindowManagerCapabilities
The bitwise negation (!) of the bits in self, truncating the result.
impl WindowManagerCapabilities
impl WindowManagerCapabilities
pub const fn iter(&self) -> Iter<WindowManagerCapabilities>
pub const fn iter(&self) -> Iter<WindowManagerCapabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<WindowManagerCapabilities>
pub const fn iter_names(&self) -> IterNames<WindowManagerCapabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.