Struct WindowState

pub struct WindowState(/* private fields */);
Available on crate feature wayland and Linux only.
The configured state of the window.

Implementations



impl WindowState

pub const MAXIMIZED: WindowState

The surface is maximized. The window geometry specified in the configure event must be obeyed by the client. The client should draw without shadow or other decoration outside of the window geometry.

pub const FULLSCREEN: WindowState

The surface is fullscreen. The window geometry specified in the configure event is a maximum; the client cannot resize beyond it. For a surface to cover the whole fullscreened area, the geometry dimensions must be obeyed by the client. For more details, see xdg_toplevel.set_fullscreen.

pub const RESIZING: WindowState

The surface is being resized. The window geometry specified in the configure event is a maximum; the client cannot resize beyond it. Clients that have aspect ratio or cell sizing configuration can use a smaller size, however.

pub const ACTIVATED: WindowState

Client window decorations should be painted as if the window is active. Do not assume this means that the window actually has keyboard or pointer focus.

pub const TILED_LEFT: WindowState

The window is currently in a tiled layout and the left edge is considered to be adjacent to another part of the tiling grid.

pub const TILED_RIGHT: WindowState

The window is currently in a tiled layout and the right edge is considered to be adjacent to another part of the tiling grid.

pub const TILED_TOP: WindowState

The window is currently in a tiled layout and the top edge is considered to be adjacent to another part of the tiling grid.

pub const TILED_BOTTOM: WindowState

The window is currently in a tiled layout and the bottom edge is considered to be adjacent to another part of the tiling grid.

pub const TILED: WindowState

An alias for all tiled bits set.

pub const SUSPENDED: WindowState

The surface is currently not ordinarily being repainted; for example because its content is occluded by another window, or its outputs are switched off due to screen locking.



impl WindowState

pub const fn empty() -> WindowState

Get a flags value with all bits unset.

pub const fn all() -> WindowState

Get a flags value with all known bits set.

pub const fn bits(&self) -> u16

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u16) -> Option<WindowState>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u16) -> WindowState

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u16) -> WindowState

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<WindowState>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: WindowState) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: WindowState) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: WindowState)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: WindowState)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: WindowState)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: WindowState, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: WindowState) -> WindowState

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: WindowState) -> WindowState

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: WindowState) -> WindowState

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: WindowState) -> WindowState

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> WindowState

The bitwise negation (!) of the bits in self, truncating the result.



impl WindowState

pub const fn iter(&self) -> Iter<WindowState>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<WindowState>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.